@@ -8,7 +8,7 @@ from redex.wildcards import *
 
 # helper functions
 
-def is_in(char, string):
+def is_in(char, string) -> bool:
     if char in wildcard.keys():
         for wchar in wildcard[char]:
             if wchar in string:
@@ -48,10 +48,10 @@ def proximity(sub_query, string) -> bool:
     threshold = int(sub_query.split('}')[1])
     max_proximity = -1
     for char in char_set:
-        proximity = abs(string.find(char)-string.find(char_set[0]))
+        proximity = abs(string.find(char) - string.find(char_set[0]))
         if is_in(char, string) and (max_proximity < proximity or max_proximity == -1):
             max_proximity = proximity
-        if char not in string:
+        if not is_in(char, string):
             return False
     return max_proximity <= threshold and max_proximity != -1
 
@@ -60,9 +60,9 @@ def sequence(sub_query, string) -> bool:
     sequence_list = list(sub_query[1:-1].split(','))
     current_index = 0
     for char in string:
-        if is_in(char, sequence_list[current_index]) and current_index < len(sequence_list) - 1:
+        if is_in(sequence_list[current_index], char) and current_index < len(sequence_list) - 1:
             current_index += 1
-        if sequence_list[current_index] not in string:
+        if not is_in(sequence_list[current_index], string):
             return False
     return current_index == len(sequence_list) - 1
 
@@ -74,3 +74,4 @@ def location(sub_query, string) -> bool:
         return is_in(char, string[location])
     else:
         return False
+
